@@ -9,7 +9,7 @@
     Released under the GNU Public Licence, Version 2.
 */
 
-#define VERSION "2.3.5"
+#define VERSION "2.3.7"
 
 #include "ksymoops.h"
 #include <ctype.h>
@@ -107,7 +107,7 @@ static void usage(void)
 	   "\t\tare\n\n"
 	   "\t\t\t"
 #ifdef DEF_VMLINUX
-	   "-v " DEF_LINUX
+	   "-v " DEF_VMLINUX
 #else
 	   "-V"
 #endif
@@ -560,7 +560,7 @@ int main(int argc, char **argv)
     setvbuf(stdout, NULL, _IONBF, 0);
 
 #ifdef DEF_VMLINUX
-    options.vmlinux = DEF_LINUX;
+    options.vmlinux = DEF_VMLINUX;
 #endif
 #ifdef DEF_KSYMS
     options.ksyms = DEF_KSYMS;
