@@ -194,9 +194,11 @@ static int section(char type)
     switch (type) {
     case 'T':
     case 't':
+    case 'W':		/* Resolved weak reference to text */
 	return 0;
     case 'D':
     case 'd':
+    case 'B':		/* Resolved weak reference to data */
 	return 1;
     case 'R':
     case 'r':
